#   ――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――
#
#   File: src/vdb-color-prompt.sh
#
#   Copyright 🄯 2003, 2004, 2008, 2013, 2025 Van de Bugger.
#
#   This file is a part of VdB color prompt.
#
#   VdB prompt is free software: you can redistribute it and/or modify it under the terms of the
#   GNU General Public License as published by the Free Software Foundation, either version 3 of
#   the License, or (at your option) any later version.
#
#   VdB color prompt is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
#   without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
#   the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License along with VdB color prompt.
#   If not, see <http://www.gnu.org/licenses/>.
#
#   SPDX-License-Identifier: GPL-3.0-or-later
#
#   ――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――

#   In 2003 I wrote the script `bash-color-prompt.sh`.
#
#   Twenty years later, in 2023, Fedora started shipping their own `bash-color-prompt.sh` script,
#   so I had to rename my script to avoid collision. So now my script is called
#   `vdb-color-prompt.sh`.

if [ -n "$BASH_VERSION" ] && [ -n "PS1" ]; then

    function vdb-color-prompt-is-ssh() {
        if [[ -n "$SSH_CLIENT" || -n "$SSH_TTY" || -n "$SSH_CONNECTION" ]]; then
            return 0
        fi
        local pid="$BASHPID"
        local comm
        local -a stat
        while [[ "$pid" -ne 0 ]]; do
            stat=( $(< /proc/$pid/stat ) )
            comm="${stat[1]}"
            if [[ "$comm" == '(sshd)' ]]; then
                return 0
            fi
            pid="${stat[3]}"
        done
        return 1
    };

    function vdb-color-prompt() {

        if [[ -n "$NO_COLOR" ]]; then

            local b=''
            local r=''
            local n=''
            local -A fg=()

            local u=''
            local h=''
            local d=''
            local s=''
            local p=''

        else

            # Color constants.          # Video attributes:
            local b=$'\e[1m'            #   bold
            local r=$'\e[7m'            #   reverse
            local n=$'\e[0m'            #   normal
            local -A fg=(               # Foreground colors:
                [ba]=$'\e[30m'          #   black
                [re]=$'\e[31m'          #   red
                [gr]=$'\e[32m'          #   green
                [ye]=$'\e[33m'          #   yellow
                [bu]=$'\e[34m'          #   blue
                [ma]=$'\e[35m'          #   magenta
                [cy]=$'\e[36m'          #   cyan
                [wh]=$'\e[37m'          #   white
            )
            case "$TERM" in     # Yellow (non-bright) is too dark on 16-color terminal.
                ( *-256color )  # Let's make it more brighter.
                    fg[ye]=$'\e[38;5;214m'
            esac

            # Semantic color variables.
            local u="$b${fg[cy]}"       # User name color.
            local h="$b${fg[ma]}"       # Host name color.
            local d="$b${fg[gr]}"       # Current dir color.
            local s=""                  # Separator (`@`, `:`) color.
            local p="$b${fg[ye]}"       # Prompt (`$`, `#`, `>`) color.
            if [[ "$UID" -eq 0 ]]; then
                u="$r${fg[re]}"         # Fix user color if user is root.
            elif [[ -f "/proc/$BASHPID/loginuid" && "$(< /proc/$BASHPID/loginuid )" != "$UID" ]]; then
                u="$r$u"                # Fix color if uid is not login uid.
            fi
            if vdb-color-prompt-is-ssh; then
                h="$r$h"                # Fix host color in case of remote system.
            fi

        fi

        PS1="\\n"
        if [[ -n "$VDB_COLOR_PROMPT" ]]; then
            PS1+="\[${fg[ye]}\]#\[$n\]$VDB_COLOR_PROMPT\\n"
        fi
        PS1+="\[$u\]\\u\[$n$s\]@\[$n$h\]\\h\[$n$s\]:\[$n$d\]\\w\[$n\]\\n"
        PS1+="\[$p\]\\\$\[$n\] "
        PS2="\[$p\]>\[$n\] "
        PS3="$p?$n "                # PS3 does not require `\[` and `\]`.

        export PS1 PS2 PS3

    }; # vdb-color-prompt

    vdb-color-prompt "$@"
    unset -f vdb-color-prompt vdb-color-prompt-is-ssh

fi

# end of file #
